@@ -35,6 +35,7 @@ CHECK_MESSAGE_EVERY_SECONDS = datetime.timedelta(days=1).total_seconds()
 CHECK_MUTES_EVERY_SECONDS = datetime.timedelta(hours=1).total_seconds()
 COMMAND_MESSAGE_DURATION = 5
 DELETE_MESSAGE_LIMIT = 100
+DISCORD_BUTTONS_MAX = 5
 DISCORD_COMMAND_PREFIX = '/'
 DISCORD_MEDIA_MAX_BYTES = 8000000
 ERROR_MESSAGE_DURATION = 10
@@ -44,6 +45,7 @@ MESSAGE_EXPIRATION_TIME = datetime.timedelta(weeks=1)
 MINIMUM_RATIO_TO_MATCH = 3
 PARSE_BUTTON_CALLBACKS_MIN_RATIO_DEFAULT = 1
 PARSE_CALLBACKS_MIN_RATIO_DEFAULT = 0.93
+PYMONGO_MEDIA_MAX_BYTES = 15000000
 RAISE_AMBIGUITY_ERROR = False
 RATIO_REWARD_EXPONENT = 2
 TELEGRAM_SEND_AS_FILE_RATIO_MIN_RATIO = 0.85
@@ -55,8 +57,8 @@ INTERROGATION_PHRASES = ('?', 'que?', 'que dise', 'no entiendo', 'no entender',
                          '🧐', '🙄', '🙃')
 
 KEYWORDS = {
-    'activate': ('activa', 'activar', 'activate', 'deja', 'dejale', 'devuelve', 'devuelvele', 'enable', 'encender',
-                 'enciende', 'habilita', 'habilitar'),
+    'activate': ('activa', 'activar', 'activate', 'add', 'añade', 'añadir', 'deja', 'dejale', 'devuelve', 'devuelvele',
+                 'enable', 'encender', 'enciende', 'habilita', 'habilitar'),
     'ban': ('ban', 'banea', 'banealo'),
     'bye': ('adieu', 'adio', 'adiooooo', 'adios', 'agur', 'buenas', 'bye', 'cama', 'chao', 'farewell', 'goodbye',
             'hasta', 'luego', 'noches', 'pronto', 'taluego', 'taluegorl', 'tenga', 'vemos', 'vista', 'voy'),
@@ -79,9 +81,12 @@ KEYWORDS = {
     'negate': ('no', 'ocurra', 'ocurre'),
     'permission': ('permiso', 'permission'),
     'reset': ('recover', 'recovery', 'recupera', 'reinicia', 'reset', 'resetea', 'restart'),
+    'role': ('rol', 'role', 'roles'),
     'send_as_file': ('arhivo', 'calidad', 'compress', 'compression', 'comprimir', 'file', 'quality'),
     'show': ('actual', 'enseña', 'estado', 'how', 'muestra', 'show', 'como'),
     'sound': ('hablar', 'hable', 'micro', 'microfono', 'microphone', 'sonido', 'sound', 'talk', 'volumen'),
+    'stop': ('acabar', 'caducar', 'detener', 'end', 'expirar', 'expire', 'finalizar', 'finish', 'parar', 'stop',
+             'suspend', 'suspender', 'terminar', 'terminate'),
     'thanks': ('gracia', 'gracias', 'grasia', 'grasias', 'grax', 'thank', 'thanks', 'ty'),
     'unban': ('desbanea', 'unban'),
     'unmute': ('desilencia', 'desmutea', 'desmutealo', 'unmute'),
